@@ -18,7 +18,7 @@
 #' @param maxit maximum number of iterations. Defaults to 1e3.
 #' @param adjmaxit adjusted maximum number of iterations. During cross validation this option allows the user to adjust the maximum number of iterations after the first \code{lam} tuning parameter has converged (for each \code{alpha}). This option is intended to be paired with \code{warm} starts and allows for 'one-step' estimators. Defaults to NULL.
 #' @param K specify the number of folds for cross validation.
-#' @param crit.cv cross validation criterion (\code{loglik}, \code{AIC}, or \code{BIC}). Defaults to \code{loglik}.
+#' @param crit.cv cross validation criterion (\code{loglik}, \code{penloglik}, \code{AIC}, or \code{BIC}). Defaults to \code{loglik}.
 #' @param start specify \code{warm} or \code{cold} start for cross validation. Default is \code{warm}.
 #' @param cores option to run CV in parallel. Defaults to \code{cores = 1}.
 #' @param trace option to display progress of CV. Choose one of \code{progress} to print a progress bar, \code{print} to print completed tuning parameters, or \code{none}.
@@ -33,9 +33,12 @@
 #' @keywords internal
 
 # we define the CV_ADMMc function
-CVP_ADMM = function(X = NULL, lam = 10^seq(-2, 2, 0.2), alpha = seq(0, 1, 0.2), diagonal = FALSE, rho = 2, mu = 10, tau.inc = 2, 
-    tau.dec = 2, crit = c("ADMM", "loglik"), tol.abs = 1e-04, tol.rel = 1e-04, maxit = 1000, adjmaxit = NULL, K = 5, crit.cv = c("loglik", 
-        "AIC", "BIC"), start = c("warm", "cold"), cores = 1, trace = c("progress", "print", "none")) {
+CVP_ADMM = function(X = NULL, lam = 10^seq(-2, 2, 0.2), alpha = seq(0, 
+    1, 0.2), diagonal = FALSE, rho = 2, mu = 10, tau.inc = 2, tau.dec = 2, 
+    crit = c("ADMM", "loglik"), tol.abs = 1e-04, tol.rel = 1e-04, 
+    maxit = 1000, adjmaxit = NULL, K = 5, crit.cv = c("loglik", 
+        "penloglik", "AIC", "BIC"), start = c("warm", "cold"), 
+    cores = 1, trace = c("progress", "print", "none")) {
     
     # match values
     crit = match.arg(crit)
@@ -48,10 +51,10 @@ CVP_ADMM = function(X = NULL, lam = 10^seq(-2, 2, 0.2), alpha = seq(0, 1, 0.2),
     # make cluster and register cluster
     num_cores = detectCores()
     if (cores > num_cores) {
-        print(paste("Only detected", num_cores, "cores...", sep = " "))
+        cat("\nOnly detected", paste(num_cores, "cores...", sep = " "))
     }
     if (cores > K) {
-        print("Number of cores exceeds K... setting cores = K")
+        cat("\nNumber of cores exceeds K... setting cores = K")
         cores = K
     }
     
@@ -62,32 +65,38 @@ CVP_ADMM = function(X = NULL, lam = 10^seq(-2, 2, 0.2), alpha = seq(0, 1, 0.2),
     n = nrow(X)
     ind = sample(n)
     k = NULL
-    CV = foreach(k = 1:K, .packages = "ADMMsigma", .inorder = FALSE) %dopar% {
-        
-        leave.out = ind[(1 + floor((k - 1) * n/K)):floor(k * n/K)]
-        
-        # training set
-        X.train = X[-leave.out, , drop = FALSE]
-        X_bar = apply(X.train, 2, mean)
-        X.train = scale(X.train, center = X_bar, scale = FALSE)
-        
-        # validation set
-        X.valid = X[leave.out, , drop = FALSE]
-        X.valid = scale(X.valid, center = X_bar, scale = FALSE)
-        
-        # sample covariances
-        S.train = crossprod(X.train)/(dim(X.train)[1])
-        S.valid = crossprod(X.valid)/(dim(X.valid)[1])
-        
-        # run foreach loop on CVP_ADMMc
-        CVP_ADMMc(n = nrow(X.valid), S_train = S.train, S_valid = S.valid, lam = lam, alpha = alpha, diagonal = diagonal, 
-            rho = rho, mu = mu, tau_inc = tau.inc, tau_dec = tau.dec, crit = crit, tol_abs = tol.abs, tol_rel = tol.rel, 
-            maxit = maxit, adjmaxit = adjmaxit, crit_cv = crit.cv, start = start, trace = trace)
-        
-    }
+    CV = foreach(k = 1:K, .packages = "ADMMsigma", .inorder = FALSE) %dopar% 
+        {
+            
+            leave.out = ind[(1 + floor((k - 1) * n/K)):floor(k * 
+                n/K)]
+            
+            # training set
+            X.train = X[-leave.out, , drop = FALSE]
+            X_bar = apply(X.train, 2, mean)
+            X.train = scale(X.train, center = X_bar, scale = FALSE)
+            
+            # validation set
+            X.valid = X[leave.out, , drop = FALSE]
+            X.valid = scale(X.valid, center = X_bar, scale = FALSE)
+            
+            # sample covariances
+            S.train = crossprod(X.train)/(dim(X.train)[1])
+            S.valid = crossprod(X.valid)/(dim(X.valid)[1])
+            
+            # run foreach loop on CVP_ADMMc
+            CVP_ADMMc(n = nrow(X.valid), S_train = S.train, S_valid = S.valid, 
+                lam = lam, alpha = alpha, diagonal = diagonal, 
+                rho = rho, mu = mu, tau_inc = tau.inc, tau_dec = tau.dec, 
+                crit = crit, tol_abs = tol.abs, tol_rel = tol.rel, 
+                maxit = maxit, adjmaxit = adjmaxit, crit_cv = crit.cv, 
+                start = start, trace = trace)
+            
+        }
     
     # determine optimal tuning parameters
-    CV = array(as.numeric(unlist(CV)), dim = c(length(lam), length(alpha), K))
+    CV = array(as.numeric(unlist(CV)), dim = c(length(lam), length(alpha), 
+        K))
     AVG = apply(CV, c(1, 2), mean)
     best = which(AVG == min(AVG), arr.ind = TRUE)
     error = min(AVG)
@@ -98,7 +107,8 @@ CVP_ADMM = function(X = NULL, lam = 10^seq(-2, 2, 0.2), alpha = seq(0, 1, 0.2),
     stopCluster(cluster)
     
     # return best lam and alpha values
-    return(list(lam = best_lam, alpha = best_alpha, min.error = error, avg.error = AVG, cv.error = CV))
+    return(list(lam = best_lam, alpha = best_alpha, min.error = error, 
+        avg.error = AVG, cv.error = CV))
     
 }
 
@@ -128,15 +138,16 @@ CVP_ADMM = function(X = NULL, lam = 10^seq(-2, 2, 0.2), alpha = seq(0, 1, 0.2),
 #' @keywords internal
 
 # we define the CVP_RIDGE function
-CVP_RIDGE = function(X = NULL, lam = 10^seq(-2, 2, 0.1), K = 5, cores = 1, trace = c("none", "progress", "print")) {
+CVP_RIDGE = function(X = NULL, lam = 10^seq(-2, 2, 0.1), K = 5, 
+    cores = 1, trace = c("none", "progress", "print")) {
     
     # make cluster and register cluster
     num_cores = detectCores()
     if (cores > num_cores) {
-        print(paste("Only detected", num_cores, "cores...", sep = " "))
+        cat("\nOnly detected", paste(num_cores, "cores...", sep = " "))
     }
     if (cores > K) {
-        print("Number of cores exceeds K... setting cores = K")
+        cat("\nNumber of cores exceeds K... setting cores = K")
         cores = K
     }
     
@@ -148,7 +159,8 @@ CVP_RIDGE = function(X = NULL, lam = 10^seq(-2, 2, 0.1), K = 5, cores = 1, trace
     ind = sample(n)
     lam = sort(lam)
     k = NULL
-    CV = foreach(k = 1:K, .packages = "ADMMsigma", .combine = "cbind", .inorder = FALSE) %dopar% {
+    CV = foreach(k = 1:K, .packages = "ADMMsigma", .combine = "cbind", 
+        .inorder = FALSE) %dopar% {
         
         leave.out = ind[(1 + floor((k - 1) * n/K)):floor(k * n/K)]
         
@@ -166,7 +178,8 @@ CVP_RIDGE = function(X = NULL, lam = 10^seq(-2, 2, 0.1), K = 5, cores = 1, trace
         S.valid = crossprod(X.valid)/(dim(X.valid)[1])
         
         # run foreach loop on CVP_RIDGEc
-        CVP_RIDGEc(n = nrow(X.valid), S_train = S.train, S_valid = S.valid, lam = lam, trace = trace)
+        CVP_RIDGEc(n = nrow(X.valid), S_train = S.train, S_valid = S.valid, 
+            lam = lam, trace = trace)
         
     }
     
@@ -180,6 +193,7 @@ CVP_RIDGE = function(X = NULL, lam = 10^seq(-2, 2, 0.1), K = 5, cores = 1, trace
     stopCluster(cluster)
     
     # return best lam and alpha values
-    return(list(lam = best_lam, min.error = error, avg.error = AVG, cv.error = CV))
+    return(list(lam = best_lam, min.error = error, avg.error = AVG, 
+        cv.error = CV))
     
 }
