@@ -60,6 +60,7 @@
 #'  }
 #'
 #' # generate 100 x 5 matrix with rows drawn from iid N_p(0, S)
+#' set.seed(123)
 #' Z = matrix(rnorm(100*5), nrow = 100, ncol = 5)
 #' out = eigen(S, symmetric = TRUE)
 #' S.sqrt = out$vectors %*% diag(out$values^0.5)
@@ -70,8 +71,9 @@
 #' RIDGEsigma(X, lam = 10^seq(-5, 5, 0.5))
 
 # we define the ADMM covariance estimation function
-RIDGEsigma = function(X = NULL, S = NULL, lam = 10^seq(-2, 2, 0.1), path = FALSE, K = 5, cores = 1, trace = c("none", "progress", 
-    "print")) {
+RIDGEsigma = function(X = NULL, S = NULL, lam = 10^seq(-2, 2, 0.1), 
+    path = FALSE, K = 5, cores = 1, trace = c("none", "progress", 
+        "print")) {
     
     # checks
     if (is.null(X) && is.null(S)) {
@@ -87,7 +89,7 @@ RIDGEsigma = function(X = NULL, S = NULL, lam = 10^seq(-2, 2, 0.1), path = FALSE
         stop("Number of cores must be positive!")
     }
     if (cores > 1 && path) {
-        print("Parallelization not possible when producing solution path. Setting cores = 1...")
+        cat("Parallelization not possible when producing solution path. Setting cores = 1...\n\n")
         cores = 1
     }
     if (path) {
@@ -114,7 +116,8 @@ RIDGEsigma = function(X = NULL, S = NULL, lam = 10^seq(-2, 2, 0.1), path = FALSE
         if (cores > 1) {
             
             # execute ParallelCV
-            RIDGE = CVP_RIDGE(X = X, lam = lam, K = K, cores = cores, trace = trace)
+            RIDGE = CVP_RIDGE(X = X, lam = lam, K = K, cores = cores, 
+                trace = trace)
             MIN.error = RIDGE$min.error
             AVG.error = RIDGE$avg.error
             CV.error = RIDGE$cv.error
@@ -126,7 +129,8 @@ RIDGEsigma = function(X = NULL, S = NULL, lam = 10^seq(-2, 2, 0.1), path = FALSE
             if (is.null(X)) {
                 X = matrix(0)
             }
-            RIDGE = CV_RIDGEc(X = X, S = S, lam = lam, path = path, K = K, trace = trace)
+            RIDGE = CV_RIDGEc(X = X, S = S, lam = lam, path = path, 
+                K = K, trace = trace)
             MIN.error = RIDGE$min.error
             AVG.error = RIDGE$avg.error
             CV.error = RIDGE$cv.error
@@ -136,8 +140,9 @@ RIDGEsigma = function(X = NULL, S = NULL, lam = 10^seq(-2, 2, 0.1), path = FALSE
         }
         
         # print warning if lam on boundary
-        if ((lam == Lambdas[1]) || (lam == Lambdas[length(Lambdas)]) && (length(Lambdas) != 1)) {
-            print("Optimal tuning parameter on boundary...!")
+        if ((lam == Lambdas[1]) || (lam == Lambdas[length(Lambdas)]) && 
+            (length(Lambdas) != 1)) {
+            cat("\nOptimal tuning parameter on boundary...!")
         }
         
         # compute final estimate at best tuning parameters
@@ -158,7 +163,8 @@ RIDGEsigma = function(X = NULL, S = NULL, lam = 10^seq(-2, 2, 0.1), path = FALSE
     grad = S - qr.solve(Omega) + lam * Omega
     
     # compute penalized loglik
-    loglik = (-n/2) * (sum(Omega * S) - determinant(Omega, logarithm = TRUE)$modulus[1] + lam * sum(Omega^2))
+    loglik = (-n/2) * (sum(Omega * S) - determinant(Omega, logarithm = TRUE)$modulus[1] + 
+        lam * sum(Omega^2))
     
     # return values
     tuning = matrix(c(log10(lam), lam), ncol = 2)
@@ -167,8 +173,10 @@ RIDGEsigma = function(X = NULL, S = NULL, lam = 10^seq(-2, 2, 0.1), path = FALSE
         Path = NULL
     }
     
-    returns = list(Call = call, Lambda = tuning, Lambdas = Lambdas, Omega = Omega, Sigma = qr.solve(Omega), Path = Path, 
-        Gradient = grad, Loglik = loglik, MIN.error = MIN.error, AVG.error = AVG.error, CV.error = CV.error)
+    returns = list(Call = call, Lambda = tuning, Lambdas = Lambdas, 
+        Omega = Omega, Sigma = qr.solve(Omega), Path = Path, Gradient = grad, 
+        Loglik = loglik, MIN.error = MIN.error, AVG.error = AVG.error, 
+        CV.error = CV.error)
     
     class(returns) = "RIDGE"
     return(returns)
@@ -192,14 +200,16 @@ RIDGEsigma = function(X = NULL, S = NULL, lam = 10^seq(-2, 2, 0.1), path = FALSE
 print.RIDGE = function(x, ...) {
     
     # print call
-    cat("\nCall: ", paste(deparse(x$Call), sep = "\n", collapse = "\n"), "\n", sep = "")
+    cat("\nCall: ", paste(deparse(x$Call), sep = "\n", collapse = "\n"), 
+        "\n", sep = "")
     
     # print optimal tuning parameter
     cat("\nTuning parameter:\n")
     print.default(round(x$Lambda, 3), print.gap = 2L, quote = FALSE)
     
     # print loglik
-    cat("\nLog-likelihood: ", paste(round(x$Loglik, 5), sep = "\n", collapse = "\n"), "\n", sep = "")
+    cat("\nLog-likelihood: ", paste(round(x$Loglik, 5), sep = "\n", 
+        collapse = "\n"), "\n", sep = "")
     
     # print Omega if dim <= 10
     if (nrow(x$Omega) <= 10) {
@@ -236,6 +246,7 @@ print.RIDGE = function(x, ...) {
 #'  }
 #'
 #' # generate 100 x 5 matrix with rows drawn from iid N_p(0, S)
+#' set.seed(123)
 #' Z = matrix(rnorm(100*5), nrow = 100, ncol = 5)
 #' out = eigen(S, symmetric = TRUE)
 #' S.sqrt = out$vectors %*% diag(out$values^0.5)
@@ -248,7 +259,8 @@ print.RIDGE = function(x, ...) {
 #' # produce line graph for RIDGEsigma
 #' plot(RIDGEsigma(X), type = 'line')
 
-plot.RIDGE = function(x, type = c("heatmap", "line"), footnote = TRUE, ...) {
+plot.RIDGE = function(x, type = c("heatmap", "line"), footnote = TRUE, 
+    ...) {
     
     # check
     type = match.arg(type)
@@ -263,8 +275,10 @@ plot.RIDGE = function(x, type = c("heatmap", "line"), footnote = TRUE, ...) {
         cv = cbind(expand.grid(lam = x$Lambdas, alpha = 0), Errors = as.data.frame.table(x$CV.error)$Freq)
         
         # produce line graph
-        graph = ggplot(summarise(group_by(cv, lam), Means = mean(Errors)), aes(log10(lam), Means)) + geom_jitter(width = 0.2, 
-            color = "navy blue") + theme_minimal() + geom_line(color = "red") + labs(title = "Cross-Validation Errors", y = "Error")
+        graph = ggplot(summarise(group_by(cv, lam), Means = mean(Errors)), 
+            aes(log10(lam), Means)) + geom_jitter(width = 0.2, 
+            color = "navy blue") + theme_minimal() + geom_line(color = "red") + 
+            labs(title = "Cross-Validation Errors", y = "Error")
         
     } else {
         
@@ -278,16 +292,19 @@ plot.RIDGE = function(x, type = c("heatmap", "line"), footnote = TRUE, ...) {
         bluetowhite <- c("#000E29", "white")
         
         # produce ggplot heat map
-        graph = ggplot(cv, aes(alpha, log10(lam))) + geom_raster(aes(fill = Errors)) + scale_fill_gradientn(colours = colorRampPalette(bluetowhite)(2), 
-            guide = "none") + theme_minimal() + labs(title = "Heatmap of Cross-Validation Errors") + theme(axis.title.x = element_blank(), 
-            axis.text.x = element_blank(), axis.ticks.x = element_blank())
+        graph = ggplot(cv, aes(alpha, log10(lam))) + geom_raster(aes(fill = Errors)) + 
+            scale_fill_gradientn(colours = colorRampPalette(bluetowhite)(2), 
+                guide = "none") + theme_minimal() + labs(title = "Heatmap of Cross-Validation Errors") + 
+            theme(axis.title.x = element_blank(), axis.text.x = element_blank(), 
+                axis.ticks.x = element_blank())
         
     }
     
     if (footnote) {
         
         # produce with footnote
-        graph + labs(caption = paste("**Optimal: log10(lam) = ", x$Lambda[1], sep = ""))
+        graph + labs(caption = paste("**Optimal: log10(lam) = ", 
+            x$Lambda[1], sep = ""))
         
     } else {
         
