@@ -59,7 +59,7 @@ arma::vec kfold(const int &n, const int &K){
 //' @param maxit maximum number of iterations. Defaults to 1e4.
 //' @param adjmaxit adjusted maximum number of iterations. During cross validation this option allows the user to adjust the maximum number of iterations after the first \code{lam} tuning parameter has converged (for each \code{alpha}). This option is intended to be paired with \code{warm} starts and allows for "one-step" estimators. Defaults to 1e4.
 //' @param K specify the number of folds for cross validation.
-//' @param crit_cv cross validation criterion (\code{loglik}, \code{AIC}, or \code{BIC}). Defaults to \code{loglik}.
+//' @param crit_cv cross validation criterion (\code{loglik} \code{penloglik}, \code{AIC}, or \code{BIC}). Defaults to \code{loglik}.
 //' @param start specify \code{warm} or \code{cold} start for cross validation. Default is \code{warm}.
 //' @param trace option to display progress of CV. Choose one of \code{progress} to print a progress bar, \code{print} to print completed tuning parameters, or \code{none}.
 //' 
@@ -79,8 +79,8 @@ List CV_ADMMc(const arma::mat &X, const arma::mat &S, const arma::colvec &lam, c
   // initialization
   int n, p = S.n_cols, l = lam.n_rows, a = alpha.n_rows, initmaxit = maxit;
   double sgn = 0, logdet = 0, initrho = rho, alpha_, lam_;
-  arma::mat X_train, X_test, S_train(S), S_test(S), Omega, initOmega, initZ2, initY;
-  arma::mat CV_error, zeros(p, p, arma::fill::zeros), zerosla(l, a, arma::fill::zeros);
+  arma::mat X_train, X_test, S_train(S), S_test(S), Omega, initOmega, initZ, initY;
+  arma::mat CV_error, zerosla(l, a, arma::fill::zeros);
   arma::uvec index, index_; arma::vec folds; arma::rowvec X_bar;
   arma::cube CV_errors(l, a, K, arma::fill::zeros), Path;
   Progress progress(l*a*K, trace == "progress");
@@ -108,8 +108,9 @@ List CV_ADMMc(const arma::mat &X, const arma::mat &S, const arma::colvec &lam, c
   for (int k = 0; k < K; k++){
     
     // re-initialize values for each fold
-    CV_error = zerosla; maxit = initmaxit;
-    initOmega = initZ2 = initY = zeros; rho = initrho;
+    CV_error = zerosla; maxit = initmaxit; rho = initrho;
+    initOmega = initZ = arma::diagmat(1/arma::diagvec(S));
+    initY = arma::zeros<arma::mat>(p, p);
       
     if (K > 1) {
       
@@ -142,14 +143,14 @@ List CV_ADMMc(const arma::mat &X, const arma::mat &S, const arma::colvec &lam, c
         alpha_ = alpha[j];
         
         // compute the ridge-penalized likelihood precision matrix estimator at the ith value in lam:
-        List ADMM = ADMMc(S_train, initOmega, initZ2, initY, lam_, alpha_, diagonal, rho, mu, tau_inc, tau_dec, crit, tol_abs, tol_rel, maxit);
+        List ADMM = ADMMc(S_train, initOmega, initZ, initY, lam_, alpha_, diagonal, rho, mu, tau_inc, tau_dec, crit, tol_abs, tol_rel, maxit);
         Omega = as<arma::mat>(ADMM["Omega"]);
         
         if (start == "warm"){
           
           // option to save initial values for warm starts
           initOmega = as<arma::mat>(ADMM["Omega"]);
-          initZ2 = as<arma::mat>(ADMM["Z2"]);
+          initZ = as<arma::mat>(ADMM["Z"]);
           initY = as<arma::mat>(ADMM["Y"]);
           rho = as<double>(ADMM["rho"]);
           maxit = adjmaxit;
@@ -161,6 +162,9 @@ List CV_ADMMc(const arma::mat &X, const arma::mat &S, const arma::colvec &lam, c
         CV_error(i, j) = (n/2)*(arma::accu(Omega % S_test) - logdet);
         
         // update for crit_cv, if necessary
+        if (crit_cv == "penloglik"){
+          CV_error(i, j) += lam_*((1 - alpha_)/2*arma::accu(arma::square(Omega)) + alpha_*arma::accu(arma::abs(Omega)));
+        }
         if (crit_cv == "AIC"){
           CV_error(i, j) += numzeros(Omega);
         }
@@ -170,7 +174,7 @@ List CV_ADMMc(const arma::mat &X, const arma::mat &S, const arma::colvec &lam, c
         
         // save estimate if path = TRUE
         if (path){
-          Path.slice(j + i*a) = as<arma::mat>(ADMM["Z2"]);
+          Path.slice(j + i*a) = as<arma::mat>(ADMM["Z"]);
         }
         
         // update progress bar
