@@ -29,7 +29,7 @@ using namespace Rcpp;
 //' @param tol_rel relative convergence tolerance. Defaults to 1e-4.
 //' @param maxit maximum number of iterations. Defaults to 1e4.
 //' @param adjmaxit adjusted maximum number of iterations. During cross validation this option allows the user to adjust the maximum number of iterations after the first \code{lam} tuning parameter has converged (for each \code{alpha}). This option is intended to be paired with \code{warm} starts and allows for "one-step" estimators. Defaults to 1e4.
-//' @param crit_cv cross validation criterion (\code{loglik}, \code{AIC}, or \code{BIC}). Defaults to \code{loglik}.
+//' @param crit_cv cross validation criterion (\code{loglik}, \code{penloglik}, \code{AIC}, or \code{BIC}). Defaults to \code{loglik}.
 //' @param start specify \code{warm} or \code{cold} start for cross validation. Default is \code{warm}.
 //' @param trace option to display progress of CV. Choose one of \code{progress} to print a progress bar, \code{print} to print completed tuning parameters, or \code{none}.
 //' 
@@ -43,8 +43,9 @@ arma::mat CVP_ADMMc(const int n, const arma::mat &S_train, const arma::mat &S_va
   // initialization
   int p = S_train.n_rows, l = lam.n_rows, a = alpha.n_rows;
   double sgn = 0, logdet = 0, alpha_, lam_;
-  arma::mat Omega, initOmega, initZ2, initY; arma::colvec nzeros;
-  initOmega = initZ2 = initY = arma::zeros<arma::mat>(p, p);
+  arma::mat Omega, initOmega, initZ, initY; arma::colvec nzeros;
+  initOmega = initZ = arma::diagmat(1/arma::diagvec(S_train));
+  initY = arma::zeros<arma::mat>(p, p);
   arma::mat CV_error(l, a, arma::fill::zeros);
   Progress progress(l*a, trace == "progress");
   
@@ -58,14 +59,14 @@ arma::mat CVP_ADMMc(const int n, const arma::mat &S_train, const arma::mat &S_va
       alpha_ = alpha[j];
       
       // compute the penalized likelihood precision matrix estimator at the ith value in lam:
-      List ADMM = ADMMc(S_train, initOmega, initZ2, initY, lam_, alpha_, diagonal, rho, mu, tau_inc, tau_dec, crit, tol_abs, tol_rel, maxit);
+      List ADMM = ADMMc(S_train, initOmega, initZ, initY, lam_, alpha_, diagonal, rho, mu, tau_inc, tau_dec, crit, tol_abs, tol_rel, maxit);
       Omega = as<arma::mat>(ADMM["Omega"]);
 
       if (start == "warm"){
         
         // option to save initial values for warm starts
         initOmega = as<arma::mat>(ADMM["Omega"]);
-        initZ2 = as<arma::mat>(ADMM["Z2"]);
+        initZ = as<arma::mat>(ADMM["Z"]);
         initY = as<arma::mat>(ADMM["Y"]);
         rho = as<double>(ADMM["rho"]);
         maxit = adjmaxit;
@@ -77,6 +78,9 @@ arma::mat CVP_ADMMc(const int n, const arma::mat &S_train, const arma::mat &S_va
       CV_error(i, j) = (n/2)*(arma::accu(Omega % S_valid) - logdet);
       
       // update for crit_cv, if necessary
+      if (crit_cv == "penloglik"){
+        CV_error(i, j) += lam_*((1 - alpha_)/2*arma::accu(arma::square(Omega)) + alpha_*arma::accu(arma::abs(Omega)));
+      }
       if (crit_cv == "AIC"){
         CV_error(i, j) += numzeros(Omega);
       }
